@@ -20,7 +20,7 @@ with 'MooseX::SimpleConfig';
 
 # For pretty man pages!
 $ENV{TERM}='xterm-256color';
-our $VERSION = '2.56';
+our $VERSION = '2.57';
 
 =head1 NAME
 
@@ -64,6 +64,12 @@ If the nodelist is supplied partition must be supplied
 
 =cut
 
+sub BUILD {
+    my $self = shift;
+    $self->logname('slurm_logs');
+    $self->log($self->init_log);
+}
+
 sub get_nodes{
     my($self) = @_;
 
